@@ -17,7 +17,7 @@
 #include <optional>
 
 struct UnitTestResult {
-    using List = QVector<UnitTestResult>;
+    using List = QList<UnitTestResult>;
     QString from;
     QStringList to;
     QStringList cc;
@@ -30,7 +30,7 @@ struct UnitTestResult {
     }
 };
 
-namespace KIdentityManagement
+namespace KIdentityManagementCore
 {
 class Identity;
 }
@@ -72,9 +72,12 @@ class AKONADI_CALENDAR_TESTS_EXPORT MailClient : public QObject
         QStringList cc;
         QString subject;
         QString body;
+        QString attachment;
+        QString method;
         bool hidden = false;
         bool bccMe = false;
-        QString attachment;
+        bool sign = false;
+        bool encrypt = false;
     };
 
     bool mAkonadiLookupEnabled = true;
@@ -82,30 +85,39 @@ class AKONADI_CALENDAR_TESTS_EXPORT MailClient : public QObject
 public:
     enum Result { ResultSuccess, ResultNoAttendees, ResultReallyNoAttendees, ResultErrorCreatingTransport, ResultErrorFetchingTransport, ResultQueueJobError };
 
+    enum MailPrivacy { MailPrivacyPlain = 0, MailPrivacySign = 1, MailPrivacyEncrypt = 2 };
+    Q_DECLARE_FLAGS(MailPrivacyFlags, MailPrivacy)
+
     explicit MailClient(ITIPHandlerComponentFactory *factory, QObject *parent = nullptr);
     ~MailClient() override;
 
     void mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidence,
-                       const KIdentityManagement::Identity &identity,
+                       const KIdentityManagementCore::Identity &identity,
+                       KCalendarCore::iTIPMethod method,
                        bool bccMe,
                        const QString &attachment = QString(),
-                       const QString &mailTransport = QString());
+                       const QString &mailTransport = QString(),
+                       MailPrivacyFlags mailPrivacy = MailPrivacyPlain);
 
     void mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidence,
-                       const KIdentityManagement::Identity &identity,
+                       const KIdentityManagementCore::Identity &identity,
                        const QString &from,
+                       KCalendarCore::iTIPMethod method,
                        bool bccMe,
                        const QString &attachment = QString(),
                        const QString &sub = QString(),
-                       const QString &mailTransport = QString());
+                       const QString &mailTransport = QString(),
+                       MailPrivacyFlags mailPrivacy = MailPrivacyPlain);
 
     void mailTo(const KCalendarCore::IncidenceBase::Ptr &incidence,
-                const KIdentityManagement::Identity &identity,
+                const KIdentityManagementCore::Identity &identity,
                 const QString &from,
+                KCalendarCore::iTIPMethod method,
                 bool bccMe,
                 const QString &recipients,
                 const QString &attachment = QString(),
-                const QString &mailTransport = QString());
+                const QString &mailTransport = QString(),
+                MailPrivacyFlags mailPrivacy = MailPrivacyPlain);
 
     /**
       Sends mail with specified from, to and subject field and body as text.
@@ -126,7 +138,7 @@ public:
       kdepimlibs/mailtransport library.
     */
     void send(const KCalendarCore::IncidenceBase::Ptr &incidence,
-              const KIdentityManagement::Identity &identity,
+              const KIdentityManagementCore::Identity &identity,
               const MessageData &msg,
               const QString &mailTransport = QString());
 
@@ -151,14 +163,14 @@ protected:
 
 private:
     std::vector<std::unique_ptr<MessageComposer::Composer>>
-    buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const MessageData &msg);
+    buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagementCore::Identity &identity, const MessageData &msg);
 
     void populateComposer(MessageComposer::Composer *composer, const MessageData &msg);
 
     bool determineWhetherToSign(bool doSignCompletely,
                                 Kleo::KeyResolver *keyResolver,
                                 ITIPHandlerDialogDelegate *dialogDelegate,
-                                const KIdentityManagement::Identity &identity,
+                                const KIdentityManagementCore::Identity &identity,
                                 bool signSomething,
                                 bool &signAttachments,
                                 bool &result,
@@ -167,21 +179,20 @@ private:
     bool determineWhetherToEncrypt(bool doEncryptCompletely,
                                    Kleo::KeyResolver *keyResolver,
                                    ITIPHandlerDialogDelegate *dialogDelegate,
-                                   const KIdentityManagement::Identity &identity,
+                                   const KIdentityManagementCore::Identity &identity,
                                    bool encryptSomething,
                                    bool signSomething,
                                    bool &encryptAttachments,
                                    bool &result,
                                    bool &canceled);
 
-    bool addKeysToContext(const QString &gnupgHome,
-                          const QVector<QPair<QStringList, std::vector<GpgME::Key>>> &data,
-                          const std::map<QByteArray, QString> &autocrypt);
+    bool
+    addKeysToContext(const QString &gnupgHome, const QList<QPair<QStringList, std::vector<GpgME::Key>>> &data, const std::map<QByteArray, QString> &autocrypt);
 
     void queueMessage(const MailTransport::Transport *transport,
                       const MessageComposer::Composer *composer,
                       const KCalendarCore::IncidenceBase::Ptr &incidence,
-                      const KIdentityManagement::Identity &identity,
+                      const KIdentityManagementCore::Identity &identity,
                       const MessageData &msg,
                       const KMime::Message::Ptr &message);
 
